Index: django_src/django/core/meta/__init__.py
===================================================================
--- django_src/django/core/meta/__init__.py	(wersja 2279)
+++ django_src/django/core/meta/__init__.py	(kopia robocza)
@@ -117,6 +117,16 @@
                 _installed_modules_cache.append(mod)
     return _installed_modules_cache
 
+_core_model_modules = []
+def get_core_model_modules():
+    " Returns a list of the core models modules."
+
+    from django.models import __all__
+    for cm in __all__:
+        _core_model_modules.append(__import__('django.models.%s' % cm, '', '',['']))
+    return _core_model_modules
+        
+    
 class LazyDate:
     """
     Use in limit_choices_to to compare the field to dates calculated at run time
Index: django_src/django/core/management.py
===================================================================
--- django_src/django/core/management.py	(wersja 2279)
+++ django_src/django/core/management.py	(kopia robocza)
@@ -397,18 +397,24 @@
 def install(mod):
     "Executes the equivalent of 'get_sql_all' in the current database."
     from django.core import db
+    from django.core.meta import get_core_model_modules
     from cStringIO import StringIO
     mod_name = mod.__name__[mod.__name__.rindex('.')+1:]
 
     # First, try validating the models.
-    s = StringIO()
-    num_errors = get_validation_errors(s)
-    if num_errors:
-        sys.stderr.write("Error: %s couldn't be installed, because there were errors in your model:\n" % mod_name)
-        s.seek(0)
-        sys.stderr.write(s.read())
-        sys.exit(1)
-    sql_list = get_sql_all(mod)
+    module_list = []
+    module_list.extend(get_core_model_modules())
+    module_list.append(mod)
+    for m in module_list:
+        mn = m.__name__[m.__name__.rindex('.')+1:]
+        s = StringIO()
+        num_errors = get_validation_errors(s, selected_mod=m)
+        if num_errors:
+            sys.stderr.write("Error: %s couldn't be installed, because there were errors in your model:\n" % mn)
+            s.seek(0)
+            sys.stderr.write(s.read())
+            sys.exit(1)
+        sql_list = get_sql_all(m)
 
     try:
         cursor = db.db.cursor()
@@ -646,12 +652,16 @@
         self.errors.append((opts, error))
         self.outfile.write("%s.%s: %s\n" % (opts.app_label, opts.module_name, error))
 
-def get_validation_errors(outfile):
-    "Validates all installed models. Writes errors, if any, to outfile. Returns number of errors."
+def get_validation_errors(outfile, selected_mod=None):
+    "Validates all installed models or models from 'selected_mod'.Writes errors, if any, to outfile.Returns number of errors."
+
     import django.models
     from django.core import meta
     e = ModelErrorCollection(outfile)
-    module_list = meta.get_installed_model_modules()
+    if not selected_mod:
+        module_list = meta.get_installed_model_modules()
+    else:
+        module_list = selected_mod,       
     for module in module_list:
         for mod in module._MODELS:
             opts = mod._meta




